@@ -23,11 +23,7 @@ class R3sponse(object):
 
 	# response functions.
 	def default_response(self):
-		return {
-			"success":False,
-			"error":None,
-			"message":None,
-		}
+		return ResponseObject()
 	def success_response(self,
 		# the message (must be param #1).
 		message, 
@@ -202,6 +198,34 @@ class R3sponse(object):
 
 		#
 
+# a response object.
+class ResponseObject(object):
+	def __init__(self):
+		self.success = False
+		self.message = None
+		self.error = "*** ResponseObject is not initialized ***"
+	# iterate over self keys & variables.
+	def items(self):
+		return vars(self).items()
+	def keys(self):
+		return list(vars(self).keys())
+	def dict(self):
+		dictionary = {}
+		for key, value in self.items():
+			dictionary[key] = value
+		return dictionary
+	# assign self variables by dictionary.
+	def assign(self, dictionary):
+		if not isinstance(dictionary, dict):
+			raise TypeError("You can only self assign with a dictionary as parameter.")
+		for key,value in dictionary.items():
+			self[key] = value
+	# support item assignment.
+	def __setitem__(self, key, value):
+		setattr(self, key, value)
+	def __getitem__(self, key):
+		return getattr(self, key)
+
 # initialized objects.
 r3sponse = R3sponse()
 
